/*

*/

#include <stdio.h>
#include <string.h>
#include <sys/types.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <netdb.h>
#include <arpa/inet.h>
#include "dv_echo.h"

void	audio_msg(char caller[], char repeater[])
{

	printf ("debug audio message %8.8s %8.8s\n", caller, repeater);
}
